@@ -103,7 +103,7 @@ function sign_message($message_obj) {
 
   # Step 1) - Load and encode the X509 cert
   $cert_obj = openssl_x509_read(file_get_contents(
-    $ssldir.'/certs/'.$certname.".pem"
+    $ssldir.'/'.$certname.".crt"
   ));
   $cert = "";
   openssl_x509_export($cert_obj, $cert);
@@ -111,7 +111,7 @@ function sign_message($message_obj) {
 
   # Step 2) - Load and sign the jsonified message with the RSA private key
   $rsa_private = openssl_get_privatekey(file_get_contents(
-    $ssldir.'/private_keys/'.$certname.".pem"
+    $ssldir.'/'.$certname.".key"
   ));
   $signature = "";
   openssl_sign($message, $signature, $rsa_private);
