@@ -11,7 +11,9 @@ handled gracefully.
 """
 
 # TODO - internationalization
-_ = lambda s: s
+import gettext
+t = gettext.translation('fedmsg', 'locale', fallback=True)
+_ = t.ugettext
 
 import fedmsg.crypto
 
@@ -19,6 +21,7 @@ from fedmsg.text.bodhi import BodhiProcessor
 from fedmsg.text.scm import SCMProcessor
 from fedmsg.text.tagger import TaggerProcessor
 from fedmsg.text.mediawiki import WikiProcessor
+from fedmsg.text.fas import FASProcessor
 from fedmsg.text.logger import LoggerProcessor
 from fedmsg.text.default import DefaultProcessor
 
@@ -27,15 +30,17 @@ processors = [
     SCMProcessor(_),
     TaggerProcessor(_),
     WikiProcessor(_),
+    FASProcessor(_),
     LoggerProcessor(_),
     DefaultProcessor(_),
 ]
 
 
 def msg2repr(msg, **config):
-    fmt = "{title} -- {subtitle}"
+    fmt = "{title} -- {subtitle} {link}"
     title = _msg2title(msg, **config)
     subtitle = _msg2subtitle(msg, **config)
+    link = _msg2link(msg, **config)
     return fmt.format(**locals())
 
 
@@ -63,6 +68,16 @@ def _msg2subtitle(msg, **config):
     # DefaultProcessor should always catch messages.
     raise RuntimeError("No text processor caught the message.")
 
+def _msg2link(msg, **config):
+    for p in processors:
+        if not p.handle_link(msg, **config):
+            continue
+        return p.link(msg, **config)
+
+    # This should never happen.
+    # DefaultProcessor should always catch messages.
+    raise RuntimeError("No text processor caught the message.")
+
 
 def _msg2suffix(msg, **config):
     if 'signature' not in msg:
